[![Build Status](https://travis-ci.com/sdrobert/pydrobert-pytorch.svg?branch=master)](https://travis-ci.com/sdrobert/pydrobert-pytorch)
[![Documentation Status](https://readthedocs.org/projects/pydrobert-pytorch/badge/?version=latest)](https://pydrobert-pytorch.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

# pydrobert-pytorch

PyTorch utilities for Machine Learning. This is an eclectic mix of utilities
that I've used in my various projects. There is a definite leaning towards
speech, specifically end-to-end ASR. The primary benefit `pydrobert-pytorch`
has over other packages is modularity: you can pick and choose the
functionality you desire without subscribing to an entire ecosystem. You can
find out more about what the package offers in the documentation links below.

**This is student-driven code, so don't expect a stable API. I'll try to use
semantic versioning, but the best way to keep functionality stable is by
pinning the version in the requirements or by forking.**

## Documentation

- [Latest](https://pydrobert-pytorch.readthedocs.io/en/latest/)
- [Stable](https://pydrobert-pytorch.readthedocs.io/en/stable/)

## Installation

`pydrobert-pytorch` is available through both Conda and PyPI.

``` bash
conda install -c sdrobert pydrobert-pytorch
pip install pydrobert-pytorch
```

## Licensing and How to Cite

Please see the [pydrobert page](https://github.com/sdrobert/pydrobert) for more
details.

Implementations of `pydrobert.torch.util.polyharmonic_spline` and
`pydrobert.torch.util.sparse_image_warp` are based off Tensorflow's codebase,
which is Apache 2.0 licensed.
